Hidex 300 SL processor
======================

This section provides step-by-step instructions on how to effectively process the CSV files provided by
the Hidex 300 SL automatic liquid scintillation counter, as well as how to
visualize and export the processed readings.
The tool that MetPyRad provides to do this is the ``Hidex300`` class.

.. toctree::
    :maxdepth: 2
    :caption: Contents

    hidex300_1
    hidex300_2
